#[repr(u32)]pub enum switch_status_t {
Show 26 variants
SWITCH_STATUS_SUCCESS = 0,
SWITCH_STATUS_FALSE = 1,
SWITCH_STATUS_TIMEOUT = 2,
SWITCH_STATUS_RESTART = 3,
SWITCH_STATUS_INTR = 4,
SWITCH_STATUS_NOTIMPL = 5,
SWITCH_STATUS_MEMERR = 6,
SWITCH_STATUS_NOOP = 7,
SWITCH_STATUS_RESAMPLE = 8,
SWITCH_STATUS_GENERR = 9,
SWITCH_STATUS_INUSE = 10,
SWITCH_STATUS_BREAK = 11,
SWITCH_STATUS_SOCKERR = 12,
SWITCH_STATUS_MORE_DATA = 13,
SWITCH_STATUS_NOTFOUND = 14,
SWITCH_STATUS_UNLOAD = 15,
SWITCH_STATUS_NOUNLOAD = 16,
SWITCH_STATUS_IGNORE = 17,
SWITCH_STATUS_TOO_SMALL = 18,
SWITCH_STATUS_FOUND = 19,
SWITCH_STATUS_CONTINUE = 20,
SWITCH_STATUS_TERM = 21,
SWITCH_STATUS_NOT_INITALIZED = 22,
SWITCH_STATUS_TOO_LATE = 23,
SWITCH_STATUS_XBREAK = 35,
SWITCH_STATUS_WINBREAK = 730_035,
}Expand description
\enum switch_status_t \brief Common return values
SWITCH_STATUS_SUCCESS - General Success (common return value for most functions) SWITCH_STATUS_FALSE - General Falsehood SWITCH_STATUS_TIMEOUT - A Timeout has occured SWITCH_STATUS_RESTART - An indication to restart the previous operation SWITCH_STATUS_TERM - An indication to terminate SWITCH_STATUS_NOTIMPL - An indication that requested resource is not impelemented SWITCH_STATUS_MEMERR - General memory error SWITCH_STATUS_NOOP - NOTHING SWITCH_STATUS_RESAMPLE - An indication that a resample has occured SWITCH_STATUS_GENERR - A general Error SWITCH_STATUS_INUSE - An indication that requested resource is in use SWITCH_STATUS_BREAK - A non-fatal break of an operation SWITCH_STATUS_SOCKERR - A socket error SWITCH_STATUS_MORE_DATA - Need More Data SWITCH_STATUS_NOTFOUND - Not Found SWITCH_STATUS_UNLOAD - Unload SWITCH_STATUS_NOUNLOAD - Never Unload
Variants
SWITCH_STATUS_SUCCESS = 0
SWITCH_STATUS_FALSE = 1
SWITCH_STATUS_TIMEOUT = 2
SWITCH_STATUS_RESTART = 3
SWITCH_STATUS_INTR = 4
SWITCH_STATUS_NOTIMPL = 5
SWITCH_STATUS_MEMERR = 6
SWITCH_STATUS_NOOP = 7
SWITCH_STATUS_RESAMPLE = 8
SWITCH_STATUS_GENERR = 9
SWITCH_STATUS_INUSE = 10
SWITCH_STATUS_BREAK = 11
SWITCH_STATUS_SOCKERR = 12
SWITCH_STATUS_MORE_DATA = 13
SWITCH_STATUS_NOTFOUND = 14
SWITCH_STATUS_UNLOAD = 15
SWITCH_STATUS_NOUNLOAD = 16
SWITCH_STATUS_IGNORE = 17
SWITCH_STATUS_TOO_SMALL = 18
SWITCH_STATUS_FOUND = 19
SWITCH_STATUS_CONTINUE = 20
SWITCH_STATUS_TERM = 21
SWITCH_STATUS_NOT_INITALIZED = 22
SWITCH_STATUS_TOO_LATE = 23
SWITCH_STATUS_XBREAK = 35
SWITCH_STATUS_WINBREAK = 730_035