switch_atomic_dec

Function switch_atomic_dec 

pub unsafe extern "C" fn switch_atomic_dec(
    mem: *mut switch_atomic_t,
) -> c_int
Uses an atomic operation to decrement the value at the specified memroy location. @param mem The location of the value to decrement.