switch_atomic_init

Function switch_atomic_init 

pub unsafe extern "C" fn switch_atomic_init(
    pool: *mut switch_memory_pool_t,
) -> switch_status_t
Some architectures require atomic operations internal structures to be initialized before use. @param pool The memory pool to use when initializing the structures.