pub unsafe extern "C" fn switch_buffer_create(
pool: *mut switch_memory_pool_t,
buffer: *mut *mut switch_buffer_t,
max_len: switch_size_t,
) -> switch_status_tExpand description
\brief Allocate a new switch_buffer \param pool Pool to allocate the buffer from \param buffer returned pointer to the new buffer \param max_len length required by the buffer \return status