switch_buffer_write

Function switch_buffer_write 

pub unsafe extern "C" fn switch_buffer_write(
    buffer: *mut switch_buffer_t,
    data: *const c_void,
    datalen: switch_size_t,
) -> switch_size_t
\brief Write data into a switch_buffer_t up to the length of datalen \param buffer any buffer of type switch_buffer_t \param data pointer to the data to be written or 0 to fill in with datalen zeros \param datalen amount of data to be written \return int amount of buffer used after the write, or 0 if no space available