pub unsafe extern "C" fn switch_cache_db_status(
stream: *mut switch_stream_handle_t,
)Expand description
\brief Provides some feedback as to the status of the db connection pool \param [in] stream stream for status
pub unsafe extern "C" fn switch_cache_db_status(
stream: *mut switch_stream_handle_t,
)\brief Provides some feedback as to the status of the db connection pool \param [in] stream stream for status