pub unsafe extern "C" fn switch_console_printf(
channel: switch_text_channel_t,
file: *const c_char,
func: *const c_char,
line: c_int,
fmt: *const c_char,
...
)Expand description
\brief A method akin to printf that allows you to redirect output to a specific console “channel”