switch_core_codec_control

Function switch_core_codec_control 

pub unsafe extern "C" fn switch_core_codec_control(
    codec: *mut switch_codec_t,
    cmd: switch_codec_control_command_t,
    ctype: switch_codec_control_type_t,
    cmd_data: *mut c_void,
    atype: switch_codec_control_type_t,
    cmd_arg: *mut c_void,
    rtype: *mut switch_codec_control_type_t,
    ret_data: *mut *mut c_void,
) -> switch_status_t
\brief send control data using a codec handle \param codec the codec handle to use \param cmd the command to send \param ctype the type of the arguement \param cmd_data a void pointer to the data matching the passed type \param atype the type of the extra arguement \param cmd_arg a void pointer to the data matching the passed type \param rtype the type of the response if any \param ret_data a void pointer to a pointer of return data \return SWITCH_STATUS_SUCCESS if the command was received