switch_core_codec_decode

Function switch_core_codec_decode 

pub unsafe extern "C" fn switch_core_codec_decode(
    codec: *mut switch_codec_t,
    other_codec: *mut switch_codec_t,
    encoded_data: *mut c_void,
    encoded_data_len: u32,
    encoded_rate: u32,
    decoded_data: *mut c_void,
    decoded_data_len: *mut u32,
    decoded_rate: *mut u32,
    flag: *mut c_uint,
) -> switch_status_t
\brief Decode data using a codec handle \param codec the codec handle to use \param other_codec the codec handle of the last codec used \param encoded_data the buffer to read the encoded data from \param encoded_data_len the size of the encoded_data buffer \param encoded_rate the rate of the encoded data \param decoded_data the raw data buffer \param decoded_data_len then length of the raw buffer \param decoded_rate the new rate of the decoded data \param flag flags to exchange \return SWITCH_STATUS_SUCCESS if the data was decoded \note decoded_data_len will be rewritten to the in-use size of decoded_data