pub unsafe extern "C" fn switch_core_codec_encode(
codec: *mut switch_codec_t,
other_codec: *mut switch_codec_t,
decoded_data: *mut c_void,
decoded_data_len: u32,
decoded_rate: u32,
encoded_data: *mut c_void,
encoded_data_len: *mut u32,
encoded_rate: *mut u32,
flag: *mut c_uint,
) -> switch_status_tExpand description
\brief Encode data using a codec handle \param codec the codec handle to use \param other_codec the codec handle of the last codec used \param decoded_data the raw data \param decoded_data_len then length of the raw buffer \param decoded_rate the rate of the decoded data \param encoded_data the buffer to write the encoded data to \param encoded_data_len the size of the encoded_data buffer \param encoded_rate the new rate of the encoded data \param flag flags to exchange \return SWITCH_STATUS_SUCCESS if the data was encoded \note encoded_data_len will be rewritten to the in-use size of encoded_data