pub unsafe extern "C" fn switch_core_db_bind_double(
pStmt: *mut switch_core_db_stmt_t,
i: c_int,
dValue: f64,
) -> c_intExpand description
In the SQL strings input to switch_core_db_prepare(), one or more literals can be replace by parameters “?” or “:AAA” or “$VVV” where AAA is an identifer and VVV is a variable name according to the syntax rules of the TCL programming language. The value of these parameters (also called “host parameter names”) can be set using the routines listed below.
In every case, the first parameter is a pointer to the sqlite3_stmt structure returned from switch_core_db_prepare(). The second parameter is the index of the parameter. The first parameter as an index of 1. For named parameters (“:AAA” or “$VVV”) you can use sqlite3_bind_parameter_index() to get the correct index value given the parameters name. If the same named parameter occurs more than once, it is assigned the same index each time.
The sqlite3_bind_* routine must be called before switch_core_db_step() after an switch_core_db_prepare() or switch_core_db_reset(). Unbound parameterss are interpreted as NULL.