pub unsafe extern "C" fn switch_core_db_changes(
db: *mut switch_core_db_t,
) -> c_intExpand description
Call this routine to find the number of rows changed by the last statement.
pub unsafe extern "C" fn switch_core_db_changes(
db: *mut switch_core_db_t,
) -> c_intCall this routine to find the number of rows changed by the last statement.