switch_core_db_errmsg

Function switch_core_db_errmsg 

pub unsafe extern "C" fn switch_core_db_errmsg(
    db: *mut switch_core_db_t,
) -> *const c_char
Return a pointer to a UTF-8 encoded string describing in english the error condition for the most recent switch_core_db_* API call. The returned string is always terminated by an 0x00 byte.

The string “not an error” is returned when the most recent API call was successful.