pub unsafe extern "C" fn switch_core_db_persistant_execute(
db: *mut switch_core_db_t,
sql: *mut c_char,
retries: u32,
) -> switch_status_tExpand description
\brief Execute a sql stmt until it is accepted \param db the db handle \param sql the sql to execute \param retries the number of retries to use \return SWITCH_STATUS_SUCCESS if successful