switch_core_file_get_string

Function switch_core_file_get_string 

pub unsafe extern "C" fn switch_core_file_get_string(
    fh: *mut switch_file_handle_t,
    col: switch_audio_col_t,
    string: *mut *const c_char,
) -> switch_status_t
\brief get metadata of the desired string \param fh the file handle to get data from \param col the enum of the col name \param string pointer to the string to fetch \return SWITCH_STATUS_SUCCESS with cur_pos adjusted to new position