switch_core_file_write

Function switch_core_file_write 

pub unsafe extern "C" fn switch_core_file_write(
    fh: *mut switch_file_handle_t,
    data: *mut c_void,
    len: *mut switch_size_t,
) -> switch_status_t
\brief Write media to a file handle \param fh the file handle to write to \param data the buffer to write \param len the amount of data to write from the buffer \return SWITCH_STATUS_SUCCESS with len adjusted to the bytes written if successful