pub unsafe extern "C" fn switch_core_hash_insert_alloc_destructor(
hash: *mut switch_hash_t,
key: *const c_char,
size: usize,
destructor: hashtable_destructor_t,
) -> *mut c_voidExpand description
\brief Allocate memory and insert into a hash \param hash the hash to add data to \param key the name of the key to add the data to \param size the size in bytes to allocate \return pointer to the allocated memory \note the string key must be a constant or a dynamic string