switch_core_hash_insert_pointer

Function switch_core_hash_insert_pointer 

pub unsafe extern "C" fn switch_core_hash_insert_pointer(
    hash: *mut switch_hash_t,
    data: *const c_void,
) -> switch_status_t
\brief Insert data into a hash with an auto-generated key based on the data pointer \param hash the hash to add data to \param data unique pointer to add \return SWITCH_STATUS_SUCCESS if the data is added