pub unsafe extern "C" fn switch_core_ready() -> switch_bool_tExpand description
\brief Determines if the core is ready to take calls \return SWITCH_TRUE or SWITCH_FALSE
pub unsafe extern "C" fn switch_core_ready() -> switch_bool_t\brief Determines if the core is ready to take calls \return SWITCH_TRUE or SWITCH_FALSE