pub unsafe extern "C" fn switch_core_set_console(
console: *const c_char,
) -> switch_status_tExpand description
\brief Set the output console to the desired file \param console the file path
pub unsafe extern "C" fn switch_core_set_console(
console: *const c_char,
) -> switch_status_t\brief Set the output console to the desired file \param console the file path