pub unsafe extern "C" fn switch_core_thread_session_end(
session: *mut switch_core_session_t,
)Expand description
\brief Signal a thread using a thread session to terminate \param session the session to indicate to
pub unsafe extern "C" fn switch_core_thread_session_end(
session: *mut switch_core_session_t,
)\brief Signal a thread using a thread session to terminate \param session the session to indicate to