switch_core_timer_init

Function switch_core_timer_init 

pub unsafe extern "C" fn switch_core_timer_init(
    timer: *mut switch_timer_t,
    timer_name: *const c_char,
    interval: c_int,
    samples: c_int,
    pool: *mut switch_memory_pool_t,
) -> switch_status_t
\defgroup timer Timer Functions \ingroup core1 { *! \brief Request a timer handle using given time module \param timer a timer object to allocate to \param timer_name the name of the timer module to use \param interval desired interval \param samples the number of samples to increment on each cycle \param pool the memory pool to use for allocation \return */