pub unsafe extern "C" fn switch_core_timer_next(
timer: *mut switch_timer_t,
) -> switch_status_tExpand description
\brief Wait for one cycle on an existing timer \param timer the timer to wait on \return the newest sample count
pub unsafe extern "C" fn switch_core_timer_next(
timer: *mut switch_timer_t,
) -> switch_status_t\brief Wait for one cycle on an existing timer \param timer the timer to wait on \return the newest sample count