switch_cut_path

Function switch_cut_path 

pub unsafe extern "C" fn switch_cut_path(
    in_: *const c_char,
) -> *const c_char
\brief Create a pointer to the file name in a given file path eliminating the directory name \return the pointer to the next character after the final / or \ characters