switch_dir_make_recursive

Function switch_dir_make_recursive 

pub unsafe extern "C" fn switch_dir_make_recursive(
    path: *const c_char,
    perm: switch_fileperms_t,
    pool: *mut switch_memory_pool_t,
) -> switch_status_t
Creates a new directory on the file system, but behaves like ‘mkdir -p’. Creates intermediate directories as required. No error will be reported if PATH already exists. @param path the path for the directory to be created. (use / on all systems) @param perm Permissions for the new direcoty. @param pool the pool to use.