pub unsafe extern "C" fn switch_file_pipe_create(
in_: *mut *mut switch_file_t,
out: *mut *mut switch_file_t,
pool: *mut switch_memory_pool_t,
) -> switch_status_tExpand description
Create an anonymous pipe. @param in The file descriptor to use as input to the pipe. @param out The file descriptor to use as output from the pipe. @param pool The pool to operate on.