pub unsafe extern "C" fn switch_file_pipe_timeout_set(
thepipe: *mut switch_file_t,
timeout: switch_interval_time_t,
) -> switch_status_tExpand description
Set the timeout value for a pipe or manipulate the blocking state. @param thepipe The pipe we are setting a timeout on. @param timeout The timeout value in microseconds. Values < 0 mean wait forever, 0 means do not wait at all.