pub unsafe extern "C" fn switch_file_write(
thefile: *mut switch_file_t,
buf: *const c_void,
nbytes: *mut switch_size_t,
) -> switch_status_tExpand description
Write data to the specified file. @param thefile The file descriptor to write to. @param buf The buffer which contains the data. @param nbytes On entry, the number of bytes to write; on exit, the number of bytes written.
@remark fspr_file_write will write up to the specified number of bytes, but never more. If the OS cannot write that many bytes, it will write as many as it can. The third argument is modified to reflect the * number of bytes written.
@remark It is possible for both bytes to be written and an error to be returned. APR_EINTR is never returned.