pub unsafe extern "C" fn switch_http_parse_header(
buffer: *mut c_char,
datalen: u32,
request: *mut switch_http_request_t,
) -> switch_status_tExpand description
parse http headers in a buffer return status of success or not \param[in] buffer the buffer start from the very begining of the http request, e.g. ’GET ’ \param[in] datalen the buffer length \param[out] the http request pointer or null, need destroy later if got non-NULL pointer \return SWITCH_STATUS_SUCCESS | SWITCH_STATUS_FALSE