switch_img_patch_rect

Function switch_img_patch_rect 

pub unsafe extern "C" fn switch_img_patch_rect(
    IMG: *mut switch_image_t,
    X: c_int,
    Y: c_int,
    img: *mut switch_image_t,
    x: u32,
    y: u32,
    w: u32,
    h: u32,
)
\brief patch part of a small img (x,y,w,h) to a big IMG at position X,Y

Both IMG and img must be non-NULL

\param[in] IMG The BIG Image descriptor \param[in] X Leftmost pos to patch to IMG \param[in] Y Topmost pos to patch to IMG \param[in] img The small Image descriptor \param[in] x Leftmost pos to be read from img \param[in] y Topmost pos to be read from \param[in] w Max width to be read from img \param[in] h Max height to be read from img