pub unsafe extern "C" fn switch_ivr_menu_bind_function(
menu: *mut switch_ivr_menu_t,
function: switch_ivr_menu_action_function_t,
arg: *const c_char,
bind: *const c_char,
) -> switch_status_tExpand description
\brief Bind a keystroke to a callback function. \param menu The menu obj you wish to bind to. \param function The function to call [int proto(struct switch_ivr_menu *, char *, size_t, void *)] \param arg Optional (sometimes necessary) string arguement. \param bind KeyStrokes to bind the action to. \note The function is passed a buffer to fill in with any required argument data. \note The function is also passed an optional void pointer to an object set upon menu execution. (think threads) \note The function returns an switch_ivr_action_t enum of what you want to do. and looks to your buffer for args. \return SWUTCH_STATUS_SUCCESS if the function was binded