switch_loadable_module_get_codecs

Function switch_loadable_module_get_codecs 

pub unsafe extern "C" fn switch_loadable_module_get_codecs(
    array: *mut *const switch_codec_implementation_t,
    arraylen: c_int,
) -> c_int
\brief Retrieve the list of loaded codecs into an array \param array the array to populate \param arraylen the max size in elements of the array \return the number of elements added to the array