pub unsafe extern "C" fn switch_loadable_module_init(
autoload: switch_bool_t,
) -> switch_status_tExpand description
\brief Initilize the module backend and load all the modules \return SWITCH_STATUS_SUCCESS when complete
pub unsafe extern "C" fn switch_loadable_module_init(
autoload: switch_bool_t,
) -> switch_status_t\brief Initilize the module backend and load all the modules \return SWITCH_STATUS_SUCCESS when complete