switch_loadable_module_load_module

Function switch_loadable_module_load_module 

pub unsafe extern "C" fn switch_loadable_module_load_module(
    dir: *const c_char,
    fname: *const c_char,
    runtime: switch_bool_t,
    err: *mut *const c_char,
) -> switch_status_t
\brief Load a module \param dir the directory where the module resides \param fname the file name of the module \param runtime option to start the runtime thread if it exists \param err pointer to error message \return the status