pub unsafe extern "C" fn switch_loadable_module_shutdown()Expand description
\brief Shutdown the module backend and call the shutdown routine in all loaded modules
pub unsafe extern "C" fn switch_loadable_module_shutdown()\brief Shutdown the module backend and call the shutdown routine in all loaded modules