switch_mutex_lock

Function switch_mutex_lock 

pub unsafe extern "C" fn switch_mutex_lock(
    lock: *mut switch_mutex_t,
) -> switch_status_t
Acquire the lock for the given mutex. If the mutex is already locked, the current thread will be put to sleep until the lock becomes available. @param lock the mutex on which to acquire the lock.