switch_pollset_create

Function switch_pollset_create 

pub unsafe extern "C" fn switch_pollset_create(
    pollset: *mut *mut switch_pollset_t,
    size: u32,
    pool: *mut switch_memory_pool_t,
    flags: u32,
) -> switch_status_t
Setup a pollset object @param pollset The pointer in which to return the newly created object @param size The maximum number of descriptors that this pollset can hold @param pool The pool from which to allocate the pollset @param flags Optional flags to modify the operation of the pollset.

@remark If flags equals APR_POLLSET_THREADSAFE, then a pollset is created on which it is safe to make concurrent calls to fspr_pollset_add(), fspr_pollset_remove() and fspr_pollset_poll() from separate threads. This feature is only supported on some platforms; the fspr_pollset_create() call will fail with APR_ENOTIMPL on platforms where it is not supported.