switch_pollset_remove

Function switch_pollset_remove 

pub unsafe extern "C" fn switch_pollset_remove(
    pollset: *mut switch_pollset_t,
    descriptor: *const switch_pollfd_t,
) -> switch_status_t
Remove a descriptor from a pollset @param pollset The pollset from which to remove the descriptor @param descriptor The descriptor to remove @remark If the pollset has been created with APR_POLLSET_THREADSAFE and thread T1 is blocked in a call to fspr_pollset_poll() for this same pollset that is being modified via fspr_pollset_remove() in thread T2, the currently executing fspr_pollset_poll() call in T1 will either: (1) automatically exclude the newly added descriptor in the set of descriptors it is watching or (2) return immediately with APR_EINTR. Option (1) is recommended, but option (2) is allowed for implementations where option (1) is impossible or impractical.