switch_queue_pop_timeout

Function switch_queue_pop_timeout 

pub unsafe extern "C" fn switch_queue_pop_timeout(
    queue: *mut switch_queue_t,
    data: *mut *mut c_void,
    timeout: switch_interval_time_t,
) -> switch_status_t
pop/get an object from the queue, blocking if the queue is already empty

@param queue the queue @param data the data @param timeout The amount of time in microseconds to wait. This is a maximum, not a minimum. If the condition is signaled, we will wake up before this time, otherwise the error APR_TIMEUP is returned. @returns APR_TIMEUP the request timed out @returns APR_EINTR the blocking was interrupted (try again) @returns APR_EOF if the queue has been terminated @returns APR_SUCCESS on a successfull pop