switch_resample_perform_create

Function switch_resample_perform_create 

pub unsafe extern "C" fn switch_resample_perform_create(
    new_resampler: *mut *mut switch_audio_resampler_t,
    from_rate: u32,
    to_rate: u32,
    to_size: u32,
    quality: c_int,
    channels: u32,
    file: *const c_char,
    func: *const c_char,
    line: c_int,
) -> switch_status_t
\brief Prepare a new resampler handle \param new_resampler NULL pointer to aim at the new handle \param from_rate the rate to transfer from in hz \param to_rate the rate to transfer to in hz \param quality the quality desired \return SWITCH_STATUS_SUCCESS if the handle was created