switch_resample_process

Function switch_resample_process 

pub unsafe extern "C" fn switch_resample_process(
    resampler: *mut switch_audio_resampler_t,
    src: *mut i16,
    srclen: u32,
) -> u32
\brief Resample one float buffer into another using specifications of a given handle \param resampler the resample handle \param src the source data \param srclen the length of the source data \return the used size of dst