switch_rtp_create

Function switch_rtp_create 

pub unsafe extern "C" fn switch_rtp_create(
    new_rtp_session: *mut *mut switch_rtp_t,
    payload: switch_payload_t,
    samples_per_interval: u32,
    ms_per_packet: u32,
    flags: *mut switch_rtp_flag_t,
    timer_name: *mut c_char,
    err: *mut *const c_char,
    pool: *mut switch_memory_pool_t,
) -> switch_status_t
\brief create a new RTP session handle \param new_rtp_session a poiter to aim at the new session \param payload the IANA payload number \param samples_per_interval the default samples_per_interval \param ms_per_packet time in microseconds per packet \param flags flags to control behaviour \param timer_name timer interface to use \param err a pointer to resolve error messages \param pool a memory pool to use for the session \return the new RTP session or NULL on failure