pub unsafe extern "C" fn switch_rtp_init(
pool: *mut switch_memory_pool_t,
)Expand description
\brief Initilize the RTP System \param pool the memory pool to use for long term allocations \note Generally called by the core_init
pub unsafe extern "C" fn switch_rtp_init(
pool: *mut switch_memory_pool_t,
)\brief Initilize the RTP System \param pool the memory pool to use for long term allocations \note Generally called by the core_init