switch_separate_string

Function switch_separate_string 

pub unsafe extern "C" fn switch_separate_string(
    buf: *mut c_char,
    delim: c_char,
    array: *mut *mut c_char,
    arraylen: c_uint,
) -> c_uint
\brief Separate a string into an array based on a character delimiter \param buf the string to parse \param delim the character delimiter \param array the array to split the values into \param arraylen the max number of elements in the array \return the number of elements added to the array