pub unsafe extern "C" fn switch_socket_connect(
sock: *mut switch_socket_t,
sa: *mut switch_sockaddr_t,
) -> switch_status_tExpand description
Issue a connection request to a socket either on the same machine or a different one. @param sock The socket we wish to use for our side of the connection @param sa The address of the machine we wish to connect to.