switch_socket_create

Function switch_socket_create 

pub unsafe extern "C" fn switch_socket_create(
    new_sock: *mut *mut switch_socket_t,
    family: c_int,
    type_: c_int,
    protocol: c_int,
    pool: *mut switch_memory_pool_t,
) -> switch_status_t
Create a socket. @param new_sock The new socket that has been set up. @param family The address family of the socket (e.g., SWITCH_INET). @param type The type of the socket (e.g., SOCK_STREAM). @param protocol The protocol of the socket (e.g., SWITCH_PROTO_TCP). @param pool The pool to use