switch_socket_create_pollfd

Function switch_socket_create_pollfd 

pub unsafe extern "C" fn switch_socket_create_pollfd(
    pollfd: *mut *mut switch_pollfd_t,
    sock: *mut switch_socket_t,
    flags: i16,
    client_data: *mut c_void,
    pool: *mut switch_memory_pool_t,
) -> switch_status_t
\brief Create a pollfd out of a socket \param pollfd the pollfd to create \param sock the socket to add \param flags the flags to modify the behaviour \param client_data custom user data \param pool the memory pool to use \return SWITCH_STATUS_SUCCESS when successful