switch_socket_create_pollset

Function switch_socket_create_pollset 

pub unsafe extern "C" fn switch_socket_create_pollset(
    poll: *mut *mut switch_pollfd_t,
    sock: *mut switch_socket_t,
    flags: i16,
    pool: *mut switch_memory_pool_t,
) -> switch_status_t
\brief Create a set of file descriptors to poll from a socket \param poll the polfd to create \param sock the socket to add \param flags the flags to modify the behaviour \param pool the memory pool to use \return SWITCH_STATUS_SUCCESS when successful