pub unsafe extern "C" fn switch_socket_fd_get(
sock: *mut switch_socket_t,
) -> c_intExpand description
Get socket fd for the switch socket passed @param sock The socket we wish to have fd
pub unsafe extern "C" fn switch_socket_fd_get(
sock: *mut switch_socket_t,
) -> c_intGet socket fd for the switch socket passed @param sock The socket we wish to have fd