pub unsafe extern "C" fn switch_str_time(
in_: *const c_char,
) -> switch_time_tExpand description
\brief Converts a string representation of a date into a switch_time_t \param in the string \return the epoch time in usec
pub unsafe extern "C" fn switch_str_time(
in_: *const c_char,
) -> switch_time_t\brief Converts a string representation of a date into a switch_time_t \param in the string \return the epoch time in usec