switch_strftime

Function switch_strftime 

pub unsafe extern "C" fn switch_strftime(
    s: *mut c_char,
    retsize: *mut switch_size_t,
    max: switch_size_t,
    format: *const c_char,
    tm: *mut switch_time_exp_t,
) -> switch_status_t
formats the exploded time according to the format specified @param s string to write to @param retsize The length of the returned string @param max The maximum length of the string @param format The format for the time string @param tm The time to convert