switch_thread_cond_create

Function switch_thread_cond_create 

pub unsafe extern "C" fn switch_thread_cond_create(
    cond: *mut *mut switch_thread_cond_t,
    pool: *mut switch_memory_pool_t,
) -> switch_status_t
Create and initialize a condition variable that can be used to signal and schedule threads in a single process. @param cond the memory address where the newly created condition variable will be stored. @param pool the pool from which to allocate the mutex.