pub unsafe extern "C" fn switch_thread_cond_destroy(
cond: *mut switch_thread_cond_t,
) -> switch_status_tExpand description
Destroy the condition variable and free the associated memory. @param cond the condition variable to destroy.
pub unsafe extern "C" fn switch_thread_cond_destroy(
cond: *mut switch_thread_cond_t,
) -> switch_status_tDestroy the condition variable and free the associated memory. @param cond the condition variable to destroy.