switch_xml_config_parse

Function switch_xml_config_parse 

pub unsafe extern "C" fn switch_xml_config_parse(
    xml: switch_xml_t,
    reload: switch_bool_t,
    instructions: *mut switch_xml_config_item_t,
) -> switch_status_t
\brief Parses all the xml elements, following a ruleset defined by an array of switch_xml_config_item_t \param xml The first element of the list to parse \param reload true to skip all non-reloadable options \param instructions instrutions on how to parse the elements \see switch_xml_config_item_t