pub unsafe extern "C" fn switch_xml_cut(
xml: switch_xml_t,
) -> switch_xml_tExpand description
\brief removes a tag along with its subtags without freeing its memory \param xml the xml node
pub unsafe extern "C" fn switch_xml_cut(
xml: switch_xml_t,
) -> switch_xml_t\brief removes a tag along with its subtags without freeing its memory \param xml the xml node