pub unsafe extern "C" fn switch_xml_error(
xml: switch_xml_t,
) -> *const c_charExpand description
\brief returns parser error message or empty string if none \param xml the xml node \return the error string or nothing
pub unsafe extern "C" fn switch_xml_error(
xml: switch_xml_t,
) -> *const c_char\brief returns parser error message or empty string if none \param xml the xml node \return the error string or nothing