pub unsafe extern "C" fn switch_xml_parse_section_string(
str_: *const c_char,
) -> switch_xml_section_tExpand description
\brief parse a string for a list of sections \param str a | delimited list of section names \return the section mask
pub unsafe extern "C" fn switch_xml_parse_section_string(
str_: *const c_char,
) -> switch_xml_section_t\brief parse a string for a list of sections \param str a | delimited list of section names \return the section mask