switch_xml_parse_str

Function switch_xml_parse_str 

pub unsafe extern "C" fn switch_xml_parse_str(
    s: *mut c_char,
    len: switch_size_t,
) -> switch_xml_t
\brief Given a string of xml data and its length, parses it and creates an switch_xml \ structure. For efficiency, modifies the data by adding null terminators \ and decoding ampersand sequences. If you don’t want this, copy the data and \ pass in the copy. Returns NULL on failure. \param s a string \param len the length of the string \return a formated xml node or NULL