pub unsafe extern "C" fn switch_xml_root() -> switch_xml_tExpand description
\brief retrieve the core XML root node \return the xml root node \note this will cause a readlock on the root until it’s released with \see switch_xml_free
pub unsafe extern "C" fn switch_xml_root() -> switch_xml_t\brief retrieve the core XML root node \return the xml root node \note this will cause a readlock on the root until it’s released with \see switch_xml_free