switch_xml_set_binding_sections

Function switch_xml_set_binding_sections 

pub unsafe extern "C" fn switch_xml_set_binding_sections(
    binding: *mut switch_xml_binding_t,
    sections: switch_xml_section_t,
)
\brief bind a search function to an external gateway \param function the search function to bind \param sections a bitmask of sections you wil service \param user_data a pointer to private data to be used during the callback \return SWITCH_STATUS_SUCCESS if successful \note gateway functions will be executed in the order they were binded until a success is found else the root registry will be used