pub unsafe extern "C" fn switch_atomic_dec(
mem: *mut switch_atomic_t,
) -> c_intExpand description
Uses an atomic operation to decrement the value at the specified memroy location. @param mem The location of the value to decrement.
pub unsafe extern "C" fn switch_atomic_dec(
mem: *mut switch_atomic_t,
) -> c_intUses an atomic operation to decrement the value at the specified memroy location. @param mem The location of the value to decrement.