pub unsafe extern "C" fn switch_buffer_create_dynamic(
buffer: *mut *mut switch_buffer_t,
blocksize: switch_size_t,
start_len: switch_size_t,
max_len: switch_size_t,
) -> switch_status_tExpand description
\brief Allocate a new dynamic switch_buffer \param buffer returned pointer to the new buffer \param blocksize length to realloc by as data is added \param start_len ammount of memory to reserve initially \param max_len length the buffer is allowed to grow to \return status