pub unsafe extern "C" fn switch_buffer_read(
buffer: *mut switch_buffer_t,
data: *mut c_void,
datalen: switch_size_t,
) -> switch_size_tExpand description
\brief Read data from a switch_buffer_t up to the ammount of datalen if it is available. Remove read data from buffer. \param buffer any buffer of type switch_buffer_t \param data pointer to the read data to be returned \param datalen amount of data to be returned \return int ammount of data actually read