pub unsafe extern "C" fn switch_buffer_read_loop(
buffer: *mut switch_buffer_t,
data: *mut c_void,
datalen: switch_size_t,
) -> switch_size_tExpand description
\brief Read data endlessly from a switch_buffer_t \param buffer any buffer of type switch_buffer_t \param data pointer to the read data to be returned \param datalen amount of data to be returned \return int ammount of data actually read \note Once you have read all the data from the buffer it will loop around.