pub unsafe extern "C" fn switch_core_codec_decode_video(
codec: *mut switch_codec_t,
frame: *mut switch_frame_t,
) -> switch_status_tExpand description
\brief Decode video data using a codec handle \param codec the codec handle to use \param frame the frame to be decoded \param img the new image in I420 format, allocated by the codec \param flag flags to exchange \return SWITCH_STATUS_SUCCESS if the data was decoded, and a non-NULL img