pub unsafe extern "C" fn switch_core_file_set_string(
fh: *mut switch_file_handle_t,
col: switch_audio_col_t,
string: *const c_char,
) -> switch_status_tExpand description
\brief Set metadata to the desired string \param fh the file handle to set data to \param col the enum of the col name \param string the string to add \return SWITCH_STATUS_SUCCESS with cur_pos adjusted to new position