pub unsafe extern "C" fn switch_core_hash_delete_multi(
hash: *mut switch_hash_t,
callback: switch_hash_delete_callback_t,
pData: *mut c_void,
) -> switch_status_tExpand description
\brief Delete data from a hash based on callback function \param hash the hash to delete from \param callback the function to call which returns SWITCH_TRUE to delete, SWITCH_FALSE to preserve \return SWITCH_STATUS_SUCCESS if any data is deleted