pub unsafe extern "C" fn switch_core_hash_init_case(
hash: *mut *mut switch_hash_t,
case_sensitive: switch_bool_t,
) -> switch_status_tExpand description
\defgroup hashf Hash Functions \ingroup core1 { *! \brief Initialize a hash table \param hash a NULL pointer to a hash table to aim at the new hash \param pool the pool to use for the new hash \return SWITCH_STATUS_SUCCESS if the hash is created */