pub unsafe extern "C" fn switch_core_sprintf(
pool: *mut switch_memory_pool_t,
fmt: *const c_char,
...
) -> *mut c_charExpand description
\brief printf-style style printing routine. The data is output to a string allocated from the pool \param pool a pool to use for allocation \param fmt The format of the string \param … The arguments to use while printing the data \return The new string