pub unsafe extern "C" fn switch_core_timer_check(
timer: *mut switch_timer_t,
step: switch_bool_t,
) -> switch_status_tExpand description
\brief Check if the current step has been exceeded \param timer the timer to wait on \param step increment timer if a tick was detected \return the newest sample count