pub unsafe extern "C" fn switch_find_interface_ip(
buf: *mut c_char,
len: c_int,
mask: *mut c_int,
ifname: *const c_char,
family: c_int,
) -> switch_status_tExpand description
\brief find primary ip of the specified interface \param buf the buffer to write the ip address found into \param len the length of the buf \param mask the CIDR found (AF_INET only) \param ifname interface name to check \param family the address family to return (AF_INET or AF_INET6) \return SWITCH_STATUS_SUCCESSS for success, otherwise failure