pub unsafe extern "C" fn switch_http_parse_qs(
request: *mut switch_http_request_t,
qs: *mut c_char,
)Expand description
parse http query string \param[in] request the http request object \param[in] qs the query string buffer
qs buffer will be modified, so be sure to dup the qs before passing into this function if you want to keep the original string untouched if qs is NULL, the it will parse request->qs, request->qs will be duplicated before parse to avoid being modified