pub unsafe extern "C" fn switch_ivr_transfer_variable(
sessa: *mut switch_core_session_t,
sessb: *mut switch_core_session_t,
var: *mut c_char,
) -> switch_status_tExpand description
\brief Transfer variables from one session to another \param sessa the original session \param sessb the new session \param var the name of the variable to transfer (NULL for all) \return SWITCH_STATUS_SUCCESS if all is well