pub unsafe extern "C" fn switch_loadable_module_build_dynamic(
filename: *mut c_char,
switch_module_load: switch_module_load_t,
switch_module_runtime: switch_module_runtime_t,
switch_module_shutdown: switch_module_shutdown_t,
runtime: switch_bool_t,
) -> switch_status_tExpand description
\brief build a dynamic module object and register it (for use in double embeded modules) \param filename the name of the modules source file \param switch_module_load the function to call when the module is loaded \param switch_module_runtime a function requested to be started in it’s own thread once loaded \param switch_module_shutdown the function to call when the system is shutdown \param runtime start the runtime thread or not \return the resulting status \note only use this function if you are making a module that in turn gateways module loading to another technology