pub unsafe extern "C" fn switch_loadable_module_get_codecs_sorted(
array: *mut *const switch_codec_implementation_t,
fmtp_array: *mut [c_char; 256],
arraylen: c_int,
prefs: *mut *mut c_char,
preflen: c_int,
) -> c_intExpand description
\brief Retrieve the list of loaded codecs into an array based on another array showing the sorted order \param array the array to populate \param arraylen the max size in elements of the array \param prefs the array of preferred codec names \param preflen the size in elements of the prefs \return the number of elements added to the array \note this function only considers codecs that are listed in the “prefs” array and ignores the rest.