pub unsafe extern "C" fn switch_loadable_module_unload_module(
dir: *const c_char,
fname: *const c_char,
force: switch_bool_t,
err: *mut *const c_char,
) -> switch_status_tExpand description
\brief Unoad a module \param dir the directory where the module resides \param fname the file name of the module \param err pointer to error message \return the status