pub unsafe extern "C" fn switch_poll(
aprset: *mut switch_pollfd_t,
numsock: i32,
nsds: *mut i32,
timeout: switch_interval_time_t,
) -> switch_status_tExpand description
Poll the sockets in the poll structure @param aprset The poll structure we will be using. @param numsock The number of sockets we are polling @param nsds The number of sockets signalled. @param timeout The amount of time in microseconds to wait. This is a maximum, not a minimum. If a socket is signalled, we will wake up before this time. A negative number means wait until a socket is signalled. @remark The number of sockets signalled is returned in the third argument. This is a blocking call, and it will not return until either a socket has been signalled, or the timeout has expired.