pub unsafe extern "C" fn switch_socket_accept(
new_sock: *mut *mut switch_socket_t,
sock: *mut switch_socket_t,
pool: *mut switch_memory_pool_t,
) -> switch_status_tExpand description
Accept a new connection request @param new_sock A copy of the socket that is connected to the socket that made the connection request. This is the socket which should be used for all future communication. @param sock The socket we are listening on. @param pool The pool for the new socket.