pub unsafe extern "C" fn switch_socket_shutdown(
sock: *mut switch_socket_t,
how: switch_shutdown_how_e,
) -> switch_status_tExpand description
Shutdown either reading, writing, or both sides of a socket. @param sock The socket to close @param how How to shutdown the socket. One of:
SWITCH_SHUTDOWN_READ no longer allow read requests
SWITCH_SHUTDOWN_WRITE no longer allow write requests
SWITCH_SHUTDOWN_READWRITE no longer allow read or write requests
@see switch_shutdown_how_e
@remark This does not actually close the socket descriptor, it just
controls which calls are still valid on the socket.