pub unsafe extern "C" fn switch_split_user_domain(
in_: *mut c_char,
user: *mut *mut c_char,
domain: *mut *mut c_char,
) -> c_intExpand description
\brief Split a user@domain string as user and domain \param in the input string \param user the string to put the user into \param domain the string to put the domain into \return 1 if successfull \note Extended formats protocol:user@domain:port (Example: sip:toto@example.org)