pub unsafe extern "C" fn switch_xml_open_root(
reload: u8,
err: *mut *const c_char,
) -> switch_xml_tExpand description
\brief open the Core xml root \param reload if it’s is already open close it and open it again as soon as permissable (blocking) \param err a pointer to set error strings \return the xml root node or NULL