pub unsafe extern "C" fn switch_xml_parse_str_dynamic(
s: *mut c_char,
dup: switch_bool_t,
) -> switch_xml_tExpand description
\brief Parses a string into a switch_xml_t, ensuring the memory will be freed with switch_xml_free \param s The string to parse \param dup true if you want the string to be strdup()’d automatically \return the switch_xml_t or NULL if an error occured